from shipyard_airbyte import AirbyteClient
import shipyard_bp_utils as shipyard
import argparse
import sys


def get_args():
    parser = argparse.ArgumentParser()
    parser.add_argument('--api-token', dest='api_token', required=True)
    parser.add_argument('--job-id', dest='job_id',
                        default=None, required=False)
    args = parser.parse_args()
    return args


def main():
    args = get_args()
    api_token = args.api_token
    job_id = args.job_id
    client = AirbyteClient(api_token)
    base_folder_name = shipyard.logs.determine_base_artifact_folder(
        'airbyte')
    artifact_subfolder_paths = shipyard.logs.determine_artifact_subfolders(
        base_folder_name)
    shipyard.logs.create_artifacts_folders(artifact_subfolder_paths)
    # check if a job id was provided, otherwise look for it in the artifact folders
    if job_id is None or job_id == '':
        response = shipyard.logs.read_pickle_file(
            artifact_subfolder_paths, 'sync_response')
        job_id = response
    job_status = client.get_sync_status(job_id=job_id)
    sync_status = client.determine_sync_status(job_status)
    sys.exit(sync_status)


if __name__ == "__main__":
    main()



import os
import sys
from shipyard_blueprints import AirbyteClient


def main():
    token = os.getenv('AIRBYTE_API_TOKEN')
    client = AirbyteClient(token)
    response = client.connect()
    if response == 200:
        sys.exit(0)
    else:
        sys.exit(1)


if __name__ == '__main__':
    main()



import argparse
import sys
import time
from shipyard_airbyte import AirbyteClient
import shipyard_bp_utils as shipyard


def get_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--connection-id", dest='connection_id', required=True)
    parser.add_argument("--api-token", dest='api_token', required=True)
    parser.add_argument("--wait-for-completion", dest='wait_for_completion')
    parser.add_argument("--poke-interval", dest='poke_interval')
    return parser.parse_args()


def generate_pickle_file(job_id):
    base_folder_name = shipyard.logs.determine_base_artifact_folder(
        'airbyte')
    artifact_subfolder_paths = shipyard.logs.determine_artifact_subfolders(
        base_folder_name)
    shipyard.logs.create_artifacts_folders(artifact_subfolder_paths)

    # save sync response as variable
    shipyard.logs.create_pickle_file(artifact_subfolder_paths,
                                     'sync_response', job_id)


def main():
    args = get_args()
    connection_id = args.connection_id
    api_token = args.api_token

    client = AirbyteClient(access_token=api_token)
    try:
        resp = client.trigger_sync(connection_id=connection_id)
    except Exception as e:
        client.logger.error(
            f"Error occurred when attempting to trigger sync due to the following error: {e}")
        sys.exit(1)

    job_id = resp['jobId']

    generate_pickle_file(job_id)  # This is for backwards compatibility the Check Sync Blueprint needs in order to run

    if args.wait_for_completion == 'TRUE' and (0 < args.poke_interval <= 60):
        status = client.determine_sync_status(job_id=job_id)
        while status not in (client.EXIT_CODE_FINAL_STATUS_COMPLETED,
                             client.EXIT_CODE_FINAL_STATUS_INCOMPLETE,
                             client.EXIT_CODE_FINAL_STATUS_CANCELLED):
            status = client.determine_sync_status(job_id=job_id)
            time.sleep(args.poke_interval)

        sys.exit(status)
    elif args.wait_for_completion == 'TRUE':
        client.logger.error(
            "Poke interval must be between 1 and 60 seconds")
        sys.exit(client.EXIT_CODE_SYNC_INVALID_POKE_INTERVAL)



if __name__ == "__main__":
    main()



from shipyard_templates import Etl
import requests
import os
import sys


class AirbyteClient(Etl):

    def __init__(self, access_token: str) -> None:
        self.access_token = access_token
        super().__init__(access_token)

    def _trigger_sync_response(self, connection_id: str) -> requests.Response:
        """ Helper function that triggers an airbyte sync and returns the response

        Args:
            connection_id: The id in which to trigger the airbyte sync

        Returns: The HTTP response from the post request
            
        """
        url = 'https://api.airbyte.com/v1/jobs'
        payload = {
            'jobType': 'sync',
            'connectionId': connection_id
        }
        headers = {
            'accept': 'application/json',
            'content-type': 'application/json',
            'authorization': f'Bearer {self.access_token}',
            'User-Agent': 'Shipyard User 1.0'
        }
        try:
            response = requests.post(url, json=payload, headers=headers)
            if response.status_code == 200:
                self.logger.info("Airbyte sync successfully triggered")
            else:
                self.logger.warn("Airbyte sync could not be triggerd")
                self.logger.warn(f"Response from the Airbyte API: {response.json()}")
                sys.exit(self.EXIT_CODE_SYNC_REFRESH_ERROR)
        except Exception as e:
            self.logger.error(
                f"Error occurred when attempting to trigger sync. Check to see that the connection id and api token are valid ")
            sys.exit(self.EXIT_CODE_BAD_REQUEST)
        return response

    def trigger_sync(self, connection_id: str) -> dict:
        """
        Args:
            connection_id: The id in which to trigger the airbyte sync
            check_status: flag to determine whether the function will check the status of the sync before exiting

        Returns: The response from the post request 

        """
        response = self._trigger_sync_response(connection_id)
        return response.json()

    def get_sync_status(self, job_id: str) -> dict:
        """ Fetches the response from the provided job

        Args:
            job_id: The associated job for the desired sync

        Returns: The HTTP response from the API
            
        """
        url = 'https://api.airbyte.com/v1/jobs'
        job_url = f"{url}/{job_id}"
        headers = {
            'accept': 'application/json',
            'authorization': f'Bearer {self.access_token}',
            'User-Agent': 'Shipyard User 1.0'
        }
        try:
            job_response = requests.get(job_url, headers=headers).json()
            job_response.raise_for_status()
        except Exception as error:
            self.logger.error(
                f"Error occurred when attempting to fetch sync status. Check to see that the job id and api token are valid. Error: {error}")
            sys.exit(self.EXIT_CODE_BAD_REQUEST)
        else:
            return job_response

    def determine_sync_status(self, job_response: dict) -> int:
        """ Provides logging and handling based off of the status. Intended to be used by the Shipyard Application only

        Args:
            job_response: The response from the get_sync_status() 

        Returns: The exit code based off of the status
            
        """
        job_status = job_response['status']
        if job_status == 'pending':
            self.logger.info(
                f"Status is pending, Airbyte job has yet to run. Sync started at {job_response['startTime']}")
            return self.EXIT_CODE_FINAL_STATUS_INCOMPLETE
        elif job_status == 'running':
            self.logger.info(
                f"Airbyte job is currently running. Sync started at {job_response['startTime']}")
            return self.EXIT_CODE_SYNC_ALREADY_RUNNING
        elif job_status == 'incomplete':
            self.logger.warn('Airbyte job status is imcomplete')
            return self.EXIT_CODE_FINAL_STATUS_INCOMPLETE
        elif job_status == 'failed':
            self.logger.warn('Airbyte job failed')
            return self.EXIT_CODE_FINAL_STATUS_ERRORED
        elif job_status == 'succeeded':
            self.logger.info(
                f"Airbyte job succeeded. Completed at {job_response['lastUpdatedAt']} with {job_response['rowsSynced']} rows synced")
            return self.EXIT_CODE_FINAL_STATUS_COMPLETED
        elif job_status == 'cancelled':
            self.logger.info('Airbyte job was cancelled')
            return self.EXIT_CODE_FINAL_STATUS_CANCELLED 

    def connect(self):
        """ Connects to the Airbyte API

        Returns: The HTTP response from the API
            
        """
        url = "https://api.airbyte.com/v1/sources"
        headers = {'authorization': f'Bearer {self.access_token}',
                   'User-Agent': 'Shipyard User 1.0'}
        response = requests.get(url, headers=headers)
        return response.status_code
